diff --git a/src/DotNetCore.CAP.RabbitMQ/CAP.RabbiMQOptions.cs b/src/DotNetCore.CAP.RabbitMQ/CAP.RabbiMQOptions.cs
index 8986bfd..6cf02a1 100644
--- a/src/DotNetCore.CAP.RabbitMQ/CAP.RabbiMQOptions.cs
+++ b/src/DotNetCore.CAP.RabbitMQ/CAP.RabbiMQOptions.cs
@@ -29,9 +29,9 @@ namespace DotNetCore.CAP
public const string DefaultVHost = "/";
///
/// Default exchange name (value: "cap").
///
- public const string DefaultExchangeName = "cap";
+ public const string DefaultExchangeName = "cap.default.topic";
/// The host to connect to.
public string HostName { get; set; } = "localhost";
@@ -29,9 +29,9 @@ namespace DotNetCore.CAP
public const string DefaultVHost = "/";
///
- /// Default exchange name (value: "cap").
+ /// Default exchange name (value: "cap.default.topic").
///